#
# spec file for package openlierox
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openlierox
Version:        0.58_rc5
Release:        5.3
Summary:        A real-time, excessive clone of Worms
License:        LGPL-2.0-or-later
Group:          Amusements/Games/Other
URL:            http://www.openlierox.net/
Source:         http://downloads.sourceforge.net/%{name}/OpenLieroX_%{version}.src.tar.bz2
# PATCH-FIX-UPSTREAM openlierox-add-missing-include.patch -- Add missing include cstdint
Patch0:         openlierox-add-missing-include.patch
BuildRequires:  SDL_image-devel
BuildRequires:  SDL_mixer-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gd-devel
BuildRequires:  hawknl-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libcurl-devel
BuildRequires:  libxml2-devel
BuildRequires:  libzip-devel
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(sdl)
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc11
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++ >= 11
%endif
# for people who try to install this using upstream capitalization
Provides:       OpenLieroX = %{version}-%{release}

%description
Based on Liero gameplay, OpenLierox is an extremely addictive realtime worms
shoot-em-up backed by an active gamers community. Dozens of levels and mods
are available to provide endless gaming pleasure.

%prep
%autosetup -n OpenLieroX -p1

%build
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
export CC="gcc-11"
export CXX="g++-11"
%endif

%cmake -DDEBUG=OFF -DBREAKPAD=OFF -DSYSTEM_DATA_DIR=%{_datadir} -DHAWKNL_BUILTIN=ON
%make_build

%install
install -m 755 -d %{buildroot}%{_datadir}/openlierox/
cp -r share/gamedir/* %{buildroot}%{_datadir}/openlierox/
find %{buildroot}%{_datadir}/openlierox/ -type f -exec chmod 0644 \{\} +

install -m 755 -d %{buildroot}%{_bindir}
install -m 755 build/bin/openlierox %{buildroot}%{_bindir}

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -p -m 644 share/OpenLieroX.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/OpenLieroX.svg

mkdir -p %{buildroot}%{_datadir}/applications
install -p -m 644 share/openlierox-openlierox.desktop %{buildroot}%{_datadir}/applications/openlierox.desktop

mkdir -p %{buildroot}%{_datadir}/appdata
install -p -m 644 share/openlierox.appdata.xml %{buildroot}%{_datadir}/appdata/openlierox.appdata.xml

%fdupes %{buildroot}%{_datadir}

%files
%{_bindir}/openlierox
%{_datadir}/openlierox
%{_datadir}/icons/hicolor/scalable/apps/OpenLieroX.svg
%{_datadir}/applications/openlierox.desktop
%{_datadir}/appdata/openlierox.appdata.xml

%changelog
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Mon Apr 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add openlierox-add-missing-include.patch: Add missing include
  cstdint. Exposed by gcc 13.
* Sat Jan 21 2023 Carsten Ziepke <kieltux@gmail.com>
- Fix building for openSUSE Leap: use gcc11
* Thu May 19 2022 Jan Engelhardt <jengelh@inai.de>
- Switch to pkgconfig(sdl) to build with sdl12_compat.
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.58_rc5
  * IPv6 support
  * Show death count in games with infinite lives
  * Navigate all menus with arrow keys. This should allow to control
    the game using only gamepad, with no mouse.
  * Fixed rope warping and explosions not drawn on infinite map.
  * Fixed desynced shots in network games.
  * Fixed invisible laser in network games.
  * New game options: mirror the map to make infinite map edges
    less obvious, and indestructible bonuses.
  * Added all player skins from Quality Skins Pack.
  * Fixed servers registering on masterserver with IPv6 address.
  * Show weapon name when picking up a bonus or when the server
    forces new weapons for a client.
- Dropped upstream merged appdata.patch and desktop.patch
- Dropped outdated patches openlierox-0.58-gcc6.patch,
  openlierox-0.58_rc1-curl.patch and openlierox-0.58_rc1-icu.patch
* Mon Feb  6 2017 mailaender@opensuse.org
- unbundle hawknl
- add desktop.patch to adhere to FreeDesktop standards properly
- add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
- add openlierox-0.58-gcc6.patch to fix the build
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Thu Oct 27 2011 tchvatal@suse.com
- Make the package actually work and build
* Thu Oct 27 2011 tchvatal@suse.com
- Initial commit of OpenLieroX, install is still broken.
